pub struct VdfStruct {
pub pairs: HashMap<String, VdfValue>,
}Expand description
Represents a Vdf Complextype with multiple key value pairs, where the value can be further nested structs
Fields
pairs: HashMap<String, VdfValue>Trait Implementations